% Jeffrey Bush
% 10/18/10
%
% function [isi_mean isi_dev] = isi(t,V)
%
% Given a function vector (V) and corresponding time vector (t), 
% isi calculates the mean interspike interval (isi_mean) and the 
% standard deviation of the interspike interval (isi_dev)
% 
% This uses an assumption that every time it spikes, the voltage increases 
% above 0.
%
% The method used here is not robust. If the data is noisy then there will
% likely be false positives. With a model however, it should work very
% well.
function [isi_mean isi_dev] = isi(t,V)
spike_thresh = 0;

time = t(V(2:end) >= spike_thresh & V(1:end-1) < spike_thresh);
dt = diff(time);

isi_mean = mean(dt);
isi_dev = std(dt);
