% Jeffrey Bush
% 10/18/10
%
% function [phase_mean isi_mean] = spk_phase(t,V1,V2)
%
% Given two function vectors (V1 and V2) and corresponding time vector (t), 
% spk_phase calculates the mean phase of the spikes in radians (phase_mean)
% and the mean interspike interval (isi_mean)
% 
% This uses an assumption that every time it spikes, the voltage increases 
% above 0.
%
% The method used here is not robust. If the data is noisy then there will
% likely be false positives. With a model however, it should work very
% well.
function [phase_mean isi_mean]=spk_phase(t,V1,V2)
spike_thresh = 0;

time1 = t(V1(2:end) >= spike_thresh & V1(1:end-1) < spike_thresh);
time2 = t(V2(2:end) >= spike_thresh & V2(1:end-1) < spike_thresh);

l = min(length(time1), length(time2));
isi_mean = mean(diff(time1));
phase_mean = mean((time1(1:l)-time2(1:l)) / isi_mean * 2 * pi);
